@@ -38,6 +38,7 @@ int put_command(char* command,char* answer,int max,int timeout,char* expect)
   int found=0;
   int available;
   int status;
+  int x;
   char loganswer[2048];
 
   // send command
@@ -64,7 +65,12 @@ int put_command(char* command,char* answer,int max,int timeout,char* expect)
     }
 #endif
     writelogfile(LOG_DEBUG,"-> %s",command);
-    write(modem,command,strlen(command));
+//    write(modem,command,strlen(command));
+    for(x=0;x<strlen(command);x++) 
+    {
+      write(modem,command+x,1);
+      usleep(1000);
+    }  
     tcdrain(modem);
   }
 
